#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from zope.interface import Interface
from zope.schema import Bool, Int, Choice
from zope.schema.vocabulary import SimpleVocabulary, SimpleTerm

from pyams_default_theme import _


VIEW_ITEMS_THUMBNAILS = (
    {'id': 'portrait', 'title': _("Portrait selection")},
    {'id': 'pano', 'title': _("Panoramic selection")},
    {'id': 'square', 'title': _("Square selection")}
)

VIEW_ITEMS_THUMBNAILS_VOCABULARY = SimpleVocabulary([SimpleTerm(item['id'], title=item['title'])
                                                     for item in VIEW_ITEMS_THUMBNAILS])


class IViewItemsPortletVerticalRendererSettings(Interface):
    """View items portlet vertical renderer settings interface"""

    display_illustrations = Bool(title=_("Display illustrations?"),
                                 description=_("If 'no', view contents will not display illustrations"),
                                 required=True,
                                 default=True)

    thumbnails_selection = Choice(title=_("Thumbnails selection"),
                                  description=_("Selection used to display images thumbnails"),
                                  vocabulary=VIEW_ITEMS_THUMBNAILS_VOCABULARY,
                                  required=True,
                                  default='pano')

    display_breadcrumbs = Bool(title=_("Display breadcrumbs?"),
                               description=_("If 'no', view items breadcrumbs will not be displayed"),
                               required=True,
                               default=True)

    display_tags = Bool(title=_("Display tags?"),
                        description=_("If 'no', view items tags will not be displayed"),
                        required=True,
                        default=True)

    paginate = Bool(title=_("Paginate?"),
                    description=_("If 'no', results pagination will be disabled"),
                    required=True,
                    default=True)

    page_size = Int(title=_("Page size"),
                    description=_("Number of items per page, if pagination is enabled"),
                    required=False,
                    default=10)


class IViewItemsPortletHorizontalRendererSettings(Interface):
    """View items portlet horizontal renderer settings interface"""

    thumbnails_selection = Choice(title=_("Thumbnails selection"),
                                  description=_("Selection used to display images thumbnails"),
                                  vocabulary=VIEW_ITEMS_THUMBNAILS_VOCABULARY,
                                  required=True,
                                  default='portrait')
